@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,7 +25,7 @@
 #include <KToggleAction>
 #include <KLocalizedString>
 #include <KNS3/DownloadDialog>
-#include <KCoreAddons/kaboutdata.h>
+#include <KAuthorized>
 #include <KActionMenu>
 #include <QDebug>
 #include <QAction>
@@ -43,23 +43,29 @@ public:
     Private(const QString &type, const QString &desktopFileName, KActionCollection *ac, const QString &relativePath, ThemeManager *qq)
         : applicationType(type)
         , defaultDesktopFileName(desktopFileName)
-        , actionGroup(0)
-        , menu(0)
+        , actionGroup(nullptr)
+        , menu(nullptr)
         , actionCollection(ac)
         , q(qq)
     {
         watch = new KDirWatch(q);
         initThemesDirectories(relativePath);
-        downloadThemesAction = new QAction(i18n("Download New Themes..."), q);
-        downloadThemesAction->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
-        if (actionCollection) {
-            actionCollection->addAction(QStringLiteral("download_header_themes"), downloadThemesAction);
+        if (KAuthorized::authorize(QStringLiteral("ghns"))) {
+            downloadThemesAction = new QAction(i18n("Download New Themes..."), q);
+            downloadThemesAction->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+            if (actionCollection) {
+                actionCollection->addAction(QStringLiteral("download_header_themes"), downloadThemesAction);
+            }
+            separatorAction = new QAction(q);
+            separatorAction->setSeparator(true);
+            q->connect(downloadThemesAction, &QAction::triggered, q, [this]() {
+                slotDownloadHeaderThemes();
+            });
         }
-        separatorAction = new QAction(q);
-        separatorAction->setSeparator(true);
 
-        q->connect(downloadThemesAction, SIGNAL(triggered(bool)), q, SLOT(slotDownloadHeaderThemes()));
-        q->connect(watch, SIGNAL(dirty(QString)), SLOT(directoryChanged()));
+        q->connect(watch, &KDirWatch::dirty, q, [this]() {
+            directoryChanged();
+        });
         updateThemesPath(true);
 
         // Migrate the old configuration format that only support mail and addressbook
@@ -174,8 +180,10 @@ public:
                 actionCollection->removeAction(action);
             }
         }
-        menu->removeAction(separatorAction);
-        menu->removeAction(downloadThemesAction);
+        if (separatorAction) {
+            menu->removeAction(separatorAction);
+            menu->removeAction(downloadThemesAction);
+        }
         themesActionList.clear();
 
         bool themeActivatedFound = false;
@@ -193,7 +201,9 @@ public:
             themesActionList.append(act);
             actionGroup->addAction(act);
             menu->addAction(act);
-            q->connect(act, SIGNAL(triggered(bool)), q, SLOT(slotThemeSelected()));
+            q->connect(act, &KToggleAction::triggered, q, [this]() {
+                slotThemeSelected();
+            });
         }
         if (!themeActivatedFound) {
             if (!themesActionList.isEmpty() && !themeActivated.isEmpty()) {
@@ -203,8 +213,10 @@ public:
                 selectTheme(act);
             }
         }
-        menu->addAction(separatorAction);
-        menu->addAction(downloadThemesAction);
+        if (separatorAction) {
+            menu->addAction(separatorAction);
+            menu->addAction(downloadThemesAction);
+        }
     }
 
     void selectTheme(KToggleAction *act)
@@ -263,13 +275,13 @@ public:
     QStringList themesDirectories;
     QMap<QString, GrantleeTheme::Theme> themes;
     QList<KToggleAction *> themesActionList;
-    KDirWatch *watch;
-    QActionGroup *actionGroup;
-    KActionMenu *menu;
-    KActionCollection *actionCollection;
-    QAction *separatorAction;
+    KDirWatch *watch = nullptr;
+    QActionGroup *actionGroup = nullptr;
+    KActionMenu *menu = nullptr;
+    KActionCollection *actionCollection = nullptr;
+    QAction *separatorAction = nullptr;
 
-    QAction *downloadThemesAction;
+    QAction *downloadThemesAction = nullptr;
     QWeakPointer<KNS3::DownloadDialog> downloadThemesDialog;
     ThemeManager *q;
 };
